<?php

namespace Litepci\Emailtemp\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litepci\Emailtemp\Models\Emailtemp;

class EmailtempPolicy
{

    /**
     * Determine if the given user can view the emailtemp.
     *
     * @param UserPolicy $user
     * @param Emailtemp $emailtemp
     *
     * @return bool
     */
    public function view(UserPolicy $user, Emailtemp $emailtemp)
    {
        if ($user->canDo('emailtemp.emailtemp.view') && $user->isAdmin()) {
            return true;
        }

        return $emailtemp->user_id == user_id() && $emailtemp->user_type == user_type();
    }

    /**
     * Determine if the given user can create a emailtemp.
     *
     * @param UserPolicy $user
     * @param Emailtemp $emailtemp
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('emailtemp.emailtemp.create');
    }

    /**
     * Determine if the given user can update the given emailtemp.
     *
     * @param UserPolicy $user
     * @param Emailtemp $emailtemp
     *
     * @return bool
     */
    public function update(UserPolicy $user, Emailtemp $emailtemp)
    {
        if ($user->canDo('emailtemp.emailtemp.edit') && $user->isAdmin()) {
            return true;
        }

        return $emailtemp->user_id == user_id() && $emailtemp->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given emailtemp.
     *
     * @param UserPolicy $user
     * @param Emailtemp $emailtemp
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Emailtemp $emailtemp)
    {
        return $emailtemp->user_id == user_id() && $emailtemp->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given emailtemp.
     *
     * @param UserPolicy $user
     * @param Emailtemp $emailtemp
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Emailtemp $emailtemp)
    {
        if ($user->canDo('emailtemp.emailtemp.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given emailtemp.
     *
     * @param UserPolicy $user
     * @param Emailtemp $emailtemp
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Emailtemp $emailtemp)
    {
        if ($user->canDo('emailtemp.emailtemp.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
