<?php

namespace Litepci\Emailtemp\Providers;

use Illuminate\Support\ServiceProvider;

class EmailtempServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'emailtemp');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'emailtemp');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerEmailtemp();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerEmailtemp()
    {
        $this->app->bind('emailtemp', function($app) {
            return new Emailtemp($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Emailtemp', 'Lavalite\Emailtemp\Facades\Emailtemp');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('litepci.emailtemp', function ($app) {
            return $this->app->make('Litepci\Emailtemp\Emailtemp');
        });

                // Bind Emailtemp to repository
        $this->app->bind(
            'Litepci\Emailtemp\Interfaces\EmailtempRepositoryInterface',
            \Litepci\Emailtemp\Repositories\Eloquent\EmailtempRepository::class
        );

        $this->app->register(\Litepci\Emailtemp\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litepci\Emailtemp\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and emailtemp's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'litepci.emailtemp'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeEmailtemp::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litepci.emailtemp'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litepci/emailtemp.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/emailtemp')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/emailtemp')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
